@@ -7,7 +7,7 @@ import math as math
 from adjustText import adjust_text
 
 
-from . import tree
+# from . import tree
 from . import per
 from . import des
 from . import notes
